==> hussar-skins-1.2.1.jar: static/bsp/permit/js/roleManage/roleEdit.js <==
/**
 * @Description: 角色管理脚本文件
 * @Author: chenxin
 * @Date: 2018/2/27.
 */

layui.use(['jquery','layer','Hussar','jstree','HussarAjax','form','element'], function(){
	var Hussar = layui.Hussar;
	var $ = layui.jquery;
	var layer=layui.layer;
	var $ax=layui.HussarAjax;
	var jstree=layui.jstree;
    var RoleManage = {};
    var element=layui.element;
    var form=layui.form;


    /*初始化页面*/
    RoleManage.initPage = function() {
        this.initTable();
        this.initResTree();
        this.initUserTree();
        this.initButtonEvent();
        this.validator();
        this.initFrameHeight();
    }

    /**
     *  加载角色关联用户树
     */
    RoleManage.initUserTree = function () {
        var nodeId=$("#nodeId").val();
        var $userTree = $("#userTree");//用户树
        $userTree.jstree({
            core: {
                check_callback: true,
                data: function (obj, callback) {
                    var data;
                    var ajax = new $ax(Hussar.ctxPath + "/roleManager/roleUserTreeEdit",
                        function(result) {
                            data = result;
                        },
                        function(data) {
                            Hussar.error("加载用户树失败!");
                        });
                    ajax.set("roleId",nodeId);
                    ajax.start();
                    callback.call(this, data);
                }
            },
            plugins: ['types','search','checkbox'],
            types:{
                "1":{'icon' : Hussar.ctxPath+"/static/assets/img/treeContext/" +theme +"/com.png"},
                "2":{'icon' : Hussar.ctxPath+"/static/assets/img/treeContext/" +theme +"/dept.png"},
                "3":{'icon' : Hussar.ctxPath+"/static/assets/img/treeContext/" +theme +"/station.png"},
                "9":{'icon' : Hussar.ctxPath+"/static/assets/img/treeContext/" +theme +"/empl.png"},
                "USER":{'icon' : Hussar.ctxPath+"/static/assets/img/treeContext/" +theme +"/user.png"},
                "isRoot":{'icon' : Hussar.ctxPath+"/static/assets/img/treeContext/" +theme +"/root.png"}
            },
            search: RoleManage.searchUser(),
            checkbox: {
                keep_selected_style : false,//是否默认选中
                three_state : true,//是否父子级别关联
                tie_selection : false
            },
        });
    };

    /**
     *  角色关联用户树查询
     */
    RoleManage.searchUser = function () {
        var to = false;
        $("#searchUser").keyup(function () {
            if (to) { clearTimeout(to); }
            to = setTimeout(function () {
                var v = $("#searchUser").val();
                var temp = $("#userTree").is(":hidden");
                if (temp == true) {
                    $("#userTree").show();
                }
                $("#userTree").jstree(true).search(v);
                //添加索引
                if(v!=''){
                    //定位到符合查询结果的树节点上
                    var searchResult = $("#userTree").jstree('search', v);
                    $(searchResult).find('.jstree-search').focus();
                }else {
                    $(".search-results1").html("");
                }
            }, 250);
        });
    };

    /**
     * 加载资源树
     */
    RoleManage.initResTree = function (roles) {
        var $retree = $("#resourceTree");//资源树
        $retree.jstree({
            core: {
                check_callback: true,
                data: function (obj, callback) {
                    var data;
                    var resource = [];
                    for(var i=0; i<roles.length; i++){
                        resource.push(roles[i].resourceId);
                    }
                    var ajax = new $ax(Hussar.ctxPath + "/resource/editResTree",function(result) {
                        data = result;
                    }, function(data) {
                        Hussar.error("加载资源树失败！");
                    });
                    ajax.set("rsourceIds",resource.join(','));
                    ajax.start();
                    callback.call(this, data);
                }
            },
            plugins: ['checkbox','search','types'],
            types:{
                "isModule":{'icon' :Hussar.ctxPath+"/static/assets/img/treeContext/" +theme +"/module.png"} ,
                "isFun":{'icon' :Hussar.ctxPath+"/static/assets/img/treeContext/" +theme +"/function.png"} ,
                "1":{'icon' :Hussar.ctxPath+"/static/assets/img/treeContext/" +theme +"/resource_menu.png"}, //菜单资源
                "2":{'icon' :Hussar.ctxPath+"/static/assets/img/treeContext/" +theme +"/resource_btn.png"},  //按钮资源
            },
            checkbox: {
                keep_selected_style : false,
                three_state : true,
                tie_selection : false
            },
            search : RoleManage.searchResource()
        });

    };

    /**
     * 资源树查询
     */
    RoleManage.searchResource = function () {
        var to = false;
        $("#searchResource").keyup(function () {
            if (to) { clearTimeout(to); }
            to = setTimeout(function () {
                var v = $("#searchResource").val();
                var temp = $("#resourceTree").is(":hidden");
                if (temp == true) {
                    $("#resourceTree").show();
                }
                $("#resourceTree").jstree(true).search(v);
                //添加索引
                if(v!=''){
                    //定位到符合查询结果的树节点上
                    var searchResult = $("#resourceTree").jstree('search', v);
                    $(searchResult).find('.jstree-search').focus();
                }else {
                    $(".search-results1").html("");
                }
            }, 250);
        });
    };

    RoleManage.initTable = function(){
        var nodeId=$("#nodeId").val();
        var ajax = new $ax(Hussar.ctxPath + "/roleManager/roleView",function(result) {
            if(result[2].length!=0){
                $("#roleMsg1").css("display","block");
                $("#groupMsg").css("display","none");
            }else{
                $("#roleMsg1").css("display","none");
                $("#groupMsg").css("display","block");
            }
            form.render();
            $('#resourceTree').jstree("destroy");
            RoleManage.initResTree(result[1]);
        },function(data) {
            Hussar.error("加载角色信息失败！");
        });
        ajax.set("id",nodeId)
        ajax.start();
    }

    /**
     * 获取选中资源id
     */
    RoleManage.getCheckedId = function () {
        var ref = $("#resourceTree").jstree(true);
        var nodes = ref.get_checked(true);  //使用get_checked方法
        var nds ='';
        $.each(nodes, function(i, nd) {
            var type=nd.original.isRes;
            if(type==1){
                nds +=","+nd.id;
            }
        });
            $("#nds").val("");//选择之前重置nds
            $("#nds").val(nds.substring(1));
    }


    /**
     * 初始化按钮事件
     */
    RoleManage.initButtonEvent = function () {
        /* 保存操作 */
        $("#saveRole").click(function(){
            form.on('submit(verify)', function(data){
                var data=$("#nodeId").val();//选中角色树的节点
                var roleName=$("#roleName").val();//角色名称
                var roleYw=$("#roleYw").val();//角色业务含义
                var ajax = new $ax(Hussar.ctxPath + "/roleManager/editRole", function (roleId) {
                    $("#roleId").val(roleId);
                    Hussar.success("角色基本信息保存成功！");
                    $("#saveRole").css("display","none");
                    $("#reset").css("display","none");
                    $("#resourceMsg").click();
                }, function () {
                    Hussar.error("保存失败！");
                });
                ajax.set("roleId",data);
                ajax.set("roleName",roleName);
                ajax.set("roleAlias",roleYw);
                ajax.start();
            });
        });

        /**
         * 保存选择资源
         */
        $("#saveResource").click(function(){
            RoleManage.getCheckedId();
            var ids=$("#nds").val();//选中资源树的节点
            var ajax = new $ax(Hussar.ctxPath + "/roleManager/saveResource", function(data) {
                Hussar.success("角色关联资源保存成功！");
                $("#userMsg").click();
            }, function(data) {
                Hussar.error("保存失败！");
            });
            ajax.set("ids",ids);
            ajax.set("roId",$("#nodeId").val());
            ajax.start();
        });

        /**
         * 保存关联用户
         */
        $("#saveUser").click(function(){
            //获取所选择的关联用户id
            var nodes = $("#userTree").jstree(true).get_checked(true);
            var userIds =[];
            $.each(nodes, function(i, nd) {
                if(nd.type == 'USER'){
                    userIds.push(nd.original.id);
                }
            });
            var ajax = new $ax(Hussar.ctxPath + "/roleManager/saveRoleUserEdit", function(data) {
                if (data.code == '200') {
                    window.parent.layui.Hussar.success("角色关联用户保存成功，请等待审核！");
                    //刷新父页面
                    window.parent.RoleManage.refreshPage();
                } else {
                    window.parent.layui.Hussar.error(data.message);
                }
            }, function(data) {
                Hussar.error("保存失败！");
            });
            ajax.set("userIds",userIds.join(','));
            ajax.set("roleId",$("#nodeId").val());
            ajax.start();
        });

    };

    /**
     * 验证表单
     */
    RoleManage.validator = function() {
        //自定义校验
        form.verify({
            required : function(value, item){
                if(value.trim()==""){
                    return '必填项不能为空！';
                }
            },
            roleName : function(value, item){
                if(!new RegExp("^[a-zA-Z0-9_\u4e00-\u9fa5\\s·]+$").test(value)){
                    return '输入项不能有特殊字符！';
                }
            },
            sameRoleName : function(value, item){
                var oldRoleName=$("#oldRoleName").val().trim();
                if(oldRoleName!=value){
                    var msg="";
                    var ajax = new $ax(Hussar.ctxPath + "/roleManager/sameRoleName", function(data) {
                        if(data.length!=0){
                            msg= '角色名称已存在！';
                        }
                    }, function(data) {
                        Hussar.error("查询角色名称是否存在失败！");
                    });
                    ajax.set("sameRoleName",value);
                    ajax.start();
                    return msg;
                }
            }
        })
    };

    RoleManage.initFrameHeight=function(){
        var h3 = $(window).height()-181;
        $("#contentInfo").css("height", h3 + "px");
    };
    /**
     * 初始化
     */
    $(function() {
        RoleManage.initPage();
        $(window).resize(function() {
            RoleManage.initFrameHeight();
        });
    });
});

==> hussar-skins-1.5.8.jar: static/bsp/permit/js/roleManage/roleEdit.js <==
/**
 * @Description: 角色管理脚本文件
 * @Author: chenxin
 * @Date: 2018/2/27.
 */

layui.use(['jquery','layer','Hussar','jstree','HussarAjax','form','element'], function(){
	var Hussar = layui.Hussar;
	var $ = layui.jquery;
	var layer=layui.layer;
	var $ax=layui.HussarAjax;
	var jstree=layui.jstree;
    var RoleManage = {};
    var element=layui.element;
    var form=layui.form;


    /*初始化页面*/
    RoleManage.initPage = function() {
        this.initTable();
        this.initResTree();
        this.initUserTree();
        this.initButtonEvent();
        this.validator();
        this.initFrameHeight();
    }

    /**
     *  加载角色关联用户树
     */
    RoleManage.initUserTree = function () {
        var nodeId=$("#nodeId").val();
        var $userTree = $("#userTree");//用户树
        $userTree.jstree({
            core: {
                check_callback: true,
                data: function (obj, callback) {
                    var data;
                    var ajax = new $ax(Hussar.ctxPath + "/roleManager/roleUserTreeEdit",
                        function(result) {
                            data = result;
                        },
                        function(data) {
                            Hussar.error("加载用户树失败!");
                        });
                    ajax.set("roleId",nodeId);
                    ajax.start();
                    callback.call(this, data);
                }
            },
            plugins: ['types','search','checkbox'],
            types:{
                "1":{'icon' : Hussar.ctxPath+"/static/assets/img/treeContext/" +theme +"/com.png"},
                "2":{'icon' : Hussar.ctxPath+"/static/assets/img/treeContext/" +theme +"/dept.png"},
                "3":{'icon' : Hussar.ctxPath+"/static/assets/img/treeContext/" +theme +"/station.png"},
                "9":{'icon' : Hussar.ctxPath+"/static/assets/img/treeContext/" +theme +"/empl.png"},
                "USER":{'icon' : Hussar.ctxPath+"/static/assets/img/treeContext/" +theme +"/user.png"},
                "isRoot":{'icon' : Hussar.ctxPath+"/static/assets/img/treeContext/" +theme +"/root.png"}
            },
            search: RoleManage.searchUser(),
            checkbox: {
                keep_selected_style : false,//是否默认选中
                three_state : true,//是否父子级别关联
                tie_selection : false
            },
        });
    };

    /**
     *  角色关联用户树查询
     */
    RoleManage.searchUser = function () {
        var to = false;
        $("#searchUser").keyup(function () {
            if (to) { clearTimeout(to); }
            to = setTimeout(function () {
                var v = $("#searchUser").val();
                var temp = $("#userTree").is(":hidden");
                if (temp == true) {
                    $("#userTree").show();
                }
                $("#userTree").jstree(true).search(v);
                //添加索引
                if(v!=''){
                    //定位到符合查询结果的树节点上
                    var searchResult = $("#userTree").jstree('search', v);
                    $(searchResult).find('.jstree-search').focus();
                }else {
                    $(".search-results1").html("");
                }
            }, 250);
        });
    };

    /**
     * 加载资源树
     */
    RoleManage.initResTree = function (roles) {
        var $retree = $("#resourceTree");//资源树
        $retree.jstree({
            core: {
                check_callback: true,
                data: function (obj, callback) {
                    var data;
                    var resource = [];
                    for(var i=0; i<roles.length; i++){
                        resource.push(roles[i].resourceId);
                    }
                    var ajax = new $ax(Hussar.ctxPath + "/resource/editResTree",function(result) {
                        data = result;
                    }, function(data) {
                        Hussar.error("加载资源树失败！");
                    });
                    ajax.set("rsourceIds",resource.join(','));
                    ajax.start();
                    callback.call(this, data);
                }
            },
            plugins: ['checkbox','search','types'],
            types:{
                "isModule":{'icon' :Hussar.ctxPath+"/static/assets/img/treeContext/" +theme +"/module.png"} ,
                "isFun":{'icon' :Hussar.ctxPath+"/static/assets/img/treeContext/" +theme +"/function.png"} ,
                "1":{'icon' :Hussar.ctxPath+"/static/assets/img/treeContext/" +theme +"/resource_menu.png"}, //菜单资源
                "2":{'icon' :Hussar.ctxPath+"/static/assets/img/treeContext/" +theme +"/resource_btn.png"},  //按钮资源
            },
            checkbox: {
                keep_selected_style : false,
                three_state : true,
                tie_selection : false
            },
            search : RoleManage.searchResource()
        });

    };

    /**
     * 资源树查询
     */
    RoleManage.searchResource = function () {
        var to = false;
        $("#searchResource").keyup(function () {
            if (to) { clearTimeout(to); }
            to = setTimeout(function () {
                var v = $("#searchResource").val();
                var temp = $("#resourceTree").is(":hidden");
                if (temp == true) {
                    $("#resourceTree").show();
                }
                $("#resourceTree").jstree(true).search(v);
                //添加索引
                if(v!=''){
                    //定位到符合查询结果的树节点上
                    var searchResult = $("#resourceTree").jstree('search', v);
                    $(searchResult).find('.jstree-search').focus();
                }else {
                    $(".search-results1").html("");
                }
            }, 250);
        });
    };

    RoleManage.initTable = function(){
        var nodeId=$("#nodeId").val();
        var ajax = new $ax(Hussar.ctxPath + "/roleManager/roleView",function(result) {
            if(result[2].length!=0){
                $("#roleMsg1").css("display","block");
                $("#groupMsg").css("display","none");
            }else{
                $("#roleMsg1").css("display","none");
                $("#groupMsg").css("display","block");
            }
            form.render();
            $('#resourceTree').jstree("destroy");
            RoleManage.initResTree(result[1]);
        },function(data) {
            Hussar.error("加载角色信息失败！");
        });
        ajax.set("id",nodeId)
        ajax.start();
    }

    /**
     * 获取选中资源id
     */
    RoleManage.getCheckedId = function () {
        var ref = $("#resourceTree").jstree(true);
        var nodes = ref.get_checked(true);  //使用get_checked方法
        var nds ='';
        $.each(nodes, function(i, nd) {
            var type=nd.original.isRes;
            if(type==1){
                nds +=","+nd.id;
            }
        });
            $("#nds").val("");//选择之前重置nds
            $("#nds").val(nds.substring(1));
    }


    /**
     * 初始化按钮事件
     */
    RoleManage.initButtonEvent = function () {
        /* 保存操作 */
        $("#saveRole").click(function(){
            form.on('submit(verify)', function(data){
                var data=$("#nodeId").val();//选中角色树的节点
                var roleName=$("#roleName").val();//角色名称
                var roleYw=$("#roleYw").val();//角色业务含义
                var ajax = new $ax(Hussar.ctxPath + "/roleManager/editRole", function (obj) {
                    if(obj.code=="200"){
                        Hussar.success("角色基本信息保存成功！");
                        $("#saveRole").css("display","none");
                        $("#reset").css("display","none");
                        $("#resourceMsg").click();
                    }else{
                        Hussar.error(obj.message+"！");
                    }
                }, function () {
                    Hussar.error("保存失败！");
                });
                ajax.set("roleId",data);
                ajax.set("roleName",roleName);
                ajax.set("roleAlias",roleYw);
                ajax.start();
            });
        });

        /**
         * 保存选择资源
         */
        $("#saveResource").click(function(){
            RoleManage.getCheckedId();
            var ids=$("#nds").val();//选中资源树的节点
            var ajax = new $ax(Hussar.ctxPath + "/roleManager/saveResource", function(data) {
                Hussar.success("角色关联资源保存成功！");
                $("#userMsg").click();
            }, function(data) {
                Hussar.error("保存失败！");
            });
            ajax.set("ids",ids);
            ajax.set("roId",$("#nodeId").val());
            ajax.start();
        });

        /**
         * 保存关联用户
         */
        $("#saveUser").click(function(){
            //获取所选择的关联用户id
            var nodes = $("#userTree").jstree(true).get_checked(true);
            var userIds =[];
            $.each(nodes, function(i, nd) {
                if(nd.type == 'USER'){
                    userIds.push(nd.original.id);
                }
            });
            var ajax = new $ax(Hussar.ctxPath + "/roleManager/saveRoleUserEdit", function(data) {
                if (data.code == '200') {
                    window.parent.layui.Hussar.success("角色关联用户保存成功！");
                    //刷新父页面
                    window.parent.RoleManage.refreshPage();
                } else {
                    window.parent.layui.Hussar.error(data.message);
                }
            }, function(data) {
                Hussar.error("保存失败！");
            });
            ajax.set("userIds",userIds.join(','));
            ajax.set("roleId",$("#nodeId").val());
            ajax.start();
        });

    };

    /**
     * 验证表单
     */
    RoleManage.validator = function() {
        //自定义校验
        form.verify({
            required : function(value, item){
                if(value.trim()==""){
                    return '必填项不能为空！';
                }
            },
            roleName : function(value, item){
                if(!new RegExp("^[a-zA-Z0-9_\u4e00-\u9fa5\\s·]+$").test(value)){
                    return '输入项不能有特殊字符！';
                }
            },
            sameRoleName : function(value, item){
                var oldRoleName=$("#oldRoleName").val().trim();
                if(oldRoleName!=value){
                    var msg="";
                    var ajax = new $ax(Hussar.ctxPath + "/roleManager/sameRoleName", function(data) {
                        if(data.length!=0){
                            msg= '角色名称已存在！';
                        }
                    }, function(data) {
                        Hussar.error("查询角色名称是否存在失败！");
                    });
                    ajax.set("sameRoleName",value);
                    ajax.start();
                    return msg;
                }
            }
        })
    };

    RoleManage.initFrameHeight=function(){
        var h3 = $(window).height()-181;
        $("#contentInfo").css("height", h3 + "px");
    };
    /**
     * 初始化
     */
    $(function() {
        RoleManage.initPage();
        $(window).resize(function() {
            RoleManage.initFrameHeight();
        });
    });
});
